==> members-facade-1.0.2-20190115.021738-13-sources.jar: com/bizvane/members/facade/vo/MbrCardLabelRefVO.java <==
package com.bizvane.members.facade.vo;

import com.bizvane.members.facade.models.po.MbrCardLabelPO;

import java.util.Date;
import java.util.List;

/**
 * Created by 26095 on 2019/1/9.
 */
public class MbrCardLabelRefVO {


    //对应的标签实体类
    private MbrCardLabelPO mbrCardLabelPO;

    public MbrCardLabelPO getMbrCardLabelPO() {
        return mbrCardLabelPO;
    }

    public void setMbrCardLabelPO(MbrCardLabelPO mbrCardLabelPO) {
        this.mbrCardLabelPO = mbrCardLabelPO;
    }

    /**
     * 只读. . mbr_brand_label_rel_id
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "", name = "mbrBrandLabelRelId", required = false, example = "")
    private Long mbrBrandLabelRelId;
    /**
     * 只读. 企业id. sys_company_id
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "企业id", name = "sysCompanyId", required = false, example = "")
    private Long sysCompanyId;
    /**
     * 只读. 品牌id. sys_brand_id
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "品牌id", name = "sysBrandId", required = false, example = "")
    private Long sysBrandId;
    /**
     * 只读. 标签id. mbr_card_label_id
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "标签id", name = "mbrCardLabelId", required = false, example = "")
    private Long mbrCardLabelId;
    /**
     * 只读. 是否必填 0:不必填 1:必填. is_must
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "是否必填 0:不必填 1:必填", name = "isMust", required = false, example = "")
    private Boolean isMust;
    /**
     * 只读. 备注. remark
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "备注", name = "remark", required = false, example = "")
    private String remark;
    /**
     * 只读. 创建人id. create_user_id
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "创建人id", name = "createUserId", required = false, example = "")
    private Long createUserId;
    /**
     * 只读. 创建人名. create_user_name
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "创建人名", name = "createUserName", required = false, example = "")
    private String createUserName;
    /**
     * 只读. 创建时间. create_date
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "创建时间", name = "createDate", required = false, example = "")
    private Date createDate;
    /**
     * 只读. 修改人id. modified_user_id
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "修改人id", name = "modifiedUserId", required = false, example = "")
    private Long modifiedUserId;
    /**
     * 只读. 修改人名. modified_user_name
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "修改人名", name = "modifiedUserName", required = false, example = "")
    private String modifiedUserName;
    /**
     * 只读. 修改时间. modified_date
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "修改时间", name = "modifiedDate", required = false, example = "")
    private Date modifiedDate;
    /**
     * 只读. 数据有效性：1=有效；0=无效. valid
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "数据有效性：1=有效；0=无效", name = "valid", required = false, example = "")
    private Boolean valid;
    /**
     * 只读. 版本号. version
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "版本号", name = "version", required = false, example = "")
    private Integer version;
    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Long getMbrBrandLabelRelId() {
        return mbrBrandLabelRelId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setMbrBrandLabelRelId(Long mbrBrandLabelRelId) {
        this.mbrBrandLabelRelId = mbrBrandLabelRelId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Long getSysBrandId() {
        return sysBrandId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Long getMbrCardLabelId() {
        return mbrCardLabelId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setMbrCardLabelId(Long mbrCardLabelId) {
        this.mbrCardLabelId = mbrCardLabelId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Boolean getIsMust() {
        return isMust;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setIsMust(Boolean isMust) {
        this.isMust = isMust;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getRemark() {
        return remark;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setRemark(String remark) {
        this.remark = remark == null ? null : remark.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Long getCreateUserId() {
        return createUserId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getCreateUserName() {
        return createUserName;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName == null ? null : createUserName.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Date getCreateDate() {
        return createDate;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Long getModifiedUserId() {
        return modifiedUserId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setModifiedUserId(Long modifiedUserId) {
        this.modifiedUserId = modifiedUserId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getModifiedUserName() {
        return modifiedUserName;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setModifiedUserName(String modifiedUserName) {
        this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Date getModifiedDate() {
        return modifiedDate;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setModifiedDate(Date modifiedDate) {
        this.modifiedDate = modifiedDate;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Boolean getValid() {
        return valid;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setValid(Boolean valid) {
        this.valid = valid;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Integer getVersion() {
        return version;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setVersion(Integer version) {
        this.version = version;
    }
}

==> members-facade-1.0.2-20190903.063157-258-sources.jar: com/bizvane/members/facade/vo/MbrCardLabelRefVO.java <==
package com.bizvane.members.facade.vo;

import com.bizvane.members.facade.models.po.MbrCardLabelPO;

import java.util.Date;
import java.util.List;

/**
 * Created by 26095 on 2019/1/9.
 */
public class MbrCardLabelRefVO {


    //对应的标签实体类
    private MbrCardLabelPO mbrCardLabelPO;

    public MbrCardLabelPO getMbrCardLabelPO() {
        return mbrCardLabelPO;
    }

    public void setMbrCardLabelPO(MbrCardLabelPO mbrCardLabelPO) {
        this.mbrCardLabelPO = mbrCardLabelPO;
    }

    /**
     * 只读. . mbr_brand_label_rel_id
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "", name = "mbrBrandLabelRelId", required = false, example = "")
    private Long mbrBrandLabelRelId;
    /**
     * 只读. 企业id. sys_company_id
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "企业id", name = "sysCompanyId", required = false, example = "")
    private Long sysCompanyId;
    /**
     * 只读. 品牌id. sys_brand_id
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "品牌id", name = "sysBrandId", required = false, example = "")
    private Long sysBrandId;
    /**
     * 只读. 标签id. mbr_card_label_id
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "标签id", name = "mbrCardLabelId", required = false, example = "")
    private Long mbrCardLabelId;
    /**
     * 只读. 是否必填 0:不必填 1:必填. is_must
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "是否必填 0:不必填 1:必填", name = "isMust", required = false, example = "")
    private Long isMust;
    /**
     * 只读. 备注. remark
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "备注", name = "remark", required = false, example = "")
    private String remark;
    /**
     * 只读. 创建人id. create_user_id
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "创建人id", name = "createUserId", required = false, example = "")
    private Long createUserId;
    /**
     * 只读. 创建人名. create_user_name
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "创建人名", name = "createUserName", required = false, example = "")
    private String createUserName;
    /**
     * 只读. 创建时间. create_date
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "创建时间", name = "createDate", required = false, example = "")
    private Date createDate;
    /**
     * 只读. 修改人id. modified_user_id
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "修改人id", name = "modifiedUserId", required = false, example = "")
    private Long modifiedUserId;
    /**
     * 只读. 修改人名. modified_user_name
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "修改人名", name = "modifiedUserName", required = false, example = "")
    private String modifiedUserName;
    /**
     * 只读. 修改时间. modified_date
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "修改时间", name = "modifiedDate", required = false, example = "")
    private Date modifiedDate;
    /**
     * 只读. 数据有效性：1=有效；0=无效. valid
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "数据有效性：1=有效；0=无效", name = "valid", required = false, example = "")
    private Boolean valid;
    /**
     * 只读. 版本号. version
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "版本号", name = "version", required = false, example = "")
    private Integer version;
    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Long getMbrBrandLabelRelId() {
        return mbrBrandLabelRelId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setMbrBrandLabelRelId(Long mbrBrandLabelRelId) {
        this.mbrBrandLabelRelId = mbrBrandLabelRelId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Long getSysBrandId() {
        return sysBrandId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Long getMbrCardLabelId() {
        return mbrCardLabelId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setMbrCardLabelId(Long mbrCardLabelId) {
        this.mbrCardLabelId = mbrCardLabelId;
    }

    public Long getIsMust() {
        return isMust;
    }

    public void setIsMust(Long isMust) {
        this.isMust = isMust;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getRemark() {
        return remark;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setRemark(String remark) {
        this.remark = remark == null ? null : remark.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Long getCreateUserId() {
        return createUserId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getCreateUserName() {
        return createUserName;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName == null ? null : createUserName.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Date getCreateDate() {
        return createDate;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Long getModifiedUserId() {
        return modifiedUserId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setModifiedUserId(Long modifiedUserId) {
        this.modifiedUserId = modifiedUserId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getModifiedUserName() {
        return modifiedUserName;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setModifiedUserName(String modifiedUserName) {
        this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Date getModifiedDate() {
        return modifiedDate;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setModifiedDate(Date modifiedDate) {
        this.modifiedDate = modifiedDate;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Boolean getValid() {
        return valid;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setValid(Boolean valid) {
        this.valid = valid;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Integer getVersion() {
        return version;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setVersion(Integer version) {
        this.version = version;
    }
}
